;; Generated package description from ada-ref-man.el  -*- no-byte-compile: t -*-
(define-package "ada-ref-man" "2020.1.0.20201129.190419" "Ada Reference Manual 2012" 'nil :commit "42a4321966c8bc6aba62cf0af1eb653d39030fd7" :authors '(("Stephen Leake" . "stephen_leake@member.fsf.org")) :maintainer '("Stephen Leake" . "stephen_leake@member.fsf.org") :keywords '("languages" "ada") :url "http://stephe-leake.org/ada/arm.html")
